@@ -1,4 +1,5 @@
 import json
+import requests
 import ssl
 
 from django.conf import settings
@@ -260,7 +261,6 @@ class FlaviusPickupLocationFileUpload(FlaviusBase):
                                                               update_url='',
                                                               delete_url='')
 
-    @staticmethod
-    def make_request_headers(content_length=0):
-        return {'Content-Type': 'multipart/form-data',
-                'Content-Length': content_length}
+    def create(self, query=None):
+        with requests.post(self.create_url, files=query, data=query) as response:
+            return json.loads(response.read().decode('utf-8'))
